@@ -17,8 +17,10 @@
 
 from __future__ import print_function
 
+
 from pyjava.api.mlsql import PythonContext
 from pyjava.utils import *
+from pyjava.cache.code_cache import CodeCache
 
 # 'resource' is a Unix specific module.
 has_resource_module = True
@@ -107,18 +109,18 @@ def main(infile, outfile):
 
         def process():
             input_data = ser.load_stream(infile)
-            code = compile(command, '<string>', 'exec')
+            code = CodeCache.get(command)
             if is_interactive:
                 global data_manager
                 global context
                 data_manager = PythonContext(input_data, conf)
                 context = data_manager
                 global globals_namespace
-                exec (code, globals_namespace, globals_namespace)
+                exec(code, globals_namespace, globals_namespace)
             else:
                 data_manager = PythonContext(input_data, conf)
                 n_local = {"data_manager": data_manager, "context": data_manager}
-                exec (code, n_local, n_local)
+                exec(code, n_local, n_local)
             out_iter = data_manager.output()
             try:
                 write_int(SpecialLengths.START_ARROW_STREAM, outfile)
